package org.artifactory.queue.register;

import lombok.AllArgsConstructor;
import org.artifactory.config.ConfigurationChangesInterceptor;
import org.artifactory.descriptor.config.CentralConfigDescriptor;
import org.springframework.stereotype.Component;

import java.util.HashSet;
import java.util.Set;

/**
 * This interceptor calls the register and deRegister methods whenever a repository is added or removed.
 *
 * @author Avishay Halpren
 */
@Component
@AllArgsConstructor
public class PersistentQueueRepositoryInterceptor implements ConfigurationChangesInterceptor {

    private final PersistentQueueRegistrationService queueRegistrationService;

    @Override
    public void onAfterSave(CentralConfigDescriptor newDescriptor, CentralConfigDescriptor oldDescriptor) {
        //find out which repo was added or removed and call the registrationService
        Set<String> reposBefore = new HashSet<>();
        reposBefore.addAll(oldDescriptor.getLocalRepositoriesMap().keySet());
        reposBefore.addAll(oldDescriptor.getFederatedRepositoriesMap().keySet());
        reposBefore.addAll(oldDescriptor.getRemoteRepositoriesMap().keySet());
        reposBefore.addAll(oldDescriptor.getVirtualRepositoriesMap().keySet());
        Set<String> reposAfter = new HashSet<>();
        reposAfter.addAll(newDescriptor.getLocalRepositoriesMap().keySet());
        reposAfter.addAll(newDescriptor.getFederatedRepositoriesMap().keySet());
        reposAfter.addAll(newDescriptor.getRemoteRepositoriesMap().keySet());
        reposAfter.addAll(newDescriptor.getVirtualRepositoriesMap().keySet());
        //if repo exist before and now doesnt -> repo was removed -> deregister
        reposBefore.stream()
                .filter((repoKey) -> !reposAfter.contains(repoKey))
                .forEach(queueRegistrationService::deRegisterRepository);
        //if repo exist now and before doesnt -> repo was added -> register
        reposAfter.stream()
                .filter((repoKey) -> !reposBefore.contains(repoKey))
                .forEach(queueRegistrationService::registerRepository);
    }
}
