package org.artifactory.queue.register;

import org.artifactory.descriptor.repo.RepoType;
import org.artifactory.queue.QueueConfiguration;
import org.artifactory.repo.RepoDetailsType;

import java.util.List;

/**
 * This is the main registration interface for the persistent queue framework.
 * Application code needs to implement this interface and return a list of QueueConfigurations
 * By implementing either getRepoType() and/or getRepoDetailsType(), code can filter out unwanted repoKeys
 *
 * @author Avishay Halpren
 */
public interface QueueConfigurationRegistrar {

    /**
     * implement this to get only repos of this type. e.g: Maven,Npm,Docker ...
     * if left empty no filter will be done on repos
     */
    default RepoType getRepoType() {
        return null;
    }

    /**
     * implement this to get only repos of this type. e.g: Local,Remote,Virtual ...
     * if left empty no filter will be done on repos
     */
    default RepoDetailsType getRepoDetailsType() {
        return null;
    }

    List<QueueConfiguration> getConfigurations(String repoKey);

}
