package org.artifactory.storage.db.security.service;

import org.artifactory.common.ConstantValues;
import org.artifactory.storage.security.service.UserLockInMemoryService;
import org.artifactory.test.ArtifactoryHomeBoundTest;
import org.testng.annotations.DataProvider;
import org.testng.annotations.Test;

import static org.fest.assertions.Assertions.assertThat;

/**
 * @author Nadav Yogev
 */
public class UserLockInMemoryServiceTest extends ArtifactoryHomeBoundTest {

    @Test(dataProvider = "dataProvider1")
    public void testNextLoginTimes1(int[] values) {
        UserLockInMemoryService lockInMemoryService = createUserLockService(128, 129, 2);
        getNextLoginTime(lockInMemoryService, values[0], values[1]);
    }

    @Test(dataProvider = "dataProvider2")
    public void testNextLoginTimes2(int[] values) {
        UserLockInMemoryService lockInMemoryService = createUserLockService(128, 512, 3);
        getNextLoginTime(lockInMemoryService, values[0], values[1]);
    }

    @Test(dataProvider = "dataProvider3")
    public void testNextLoginTimes3(int[] values) {
        UserLockInMemoryService lockInMemoryService = createUserLockService(128, 256, 1);
        getNextLoginTime(lockInMemoryService, values[0], values[1]);
    }

    @Test(dataProvider = "dataProvider4")
    public void testNextLoginTimesDefaultBehavior(int[] values) {
        UserLockInMemoryService lockInMemoryService =
                createUserLockService(Integer.parseInt(ConstantValues.loginBlockDelayMillis.getDefValue()),
                        Integer.parseInt(ConstantValues.loginMaxBlockDelayMillis.getDefValue()),
                        Integer.parseInt(ConstantValues.maxIncorrectLoginAttempts.getDefValue())); //default behaviour
        getNextLoginTime(lockInMemoryService, values[0], values[1]);
    }

    @Test(dataProvider = "testZeroBlockDelayDataProvider")
    public void testZeroBlockDelay(int[] values) {
        UserLockInMemoryServiceImpl lockInMemoryService = createUserLockService(0, 1000, 2);
        getNextLoginTime(lockInMemoryService, values[0], values[1]);
    }

    @Test(dataProvider = "testZeroMaxDelayDataProvider")
    public void testZeroMaxDelay(int[] values) {
        UserLockInMemoryServiceImpl lockInMemoryService = createUserLockService(128, 0, 2);
        getNextLoginTime(lockInMemoryService, values[0], values[1]);
    }

    private UserLockInMemoryServiceImpl createUserLockService(int loginBlockDelay, int loginMaxDelay, int maxAttempts) {
        getBound().setProperty(ConstantValues.loginBlockDelayMillis, String.valueOf(loginBlockDelay));
        getBound().setProperty(ConstantValues.loginMaxBlockDelayMillis, String.valueOf(loginMaxDelay));
        getBound().setProperty(ConstantValues.maxIncorrectLoginAttempts, String.valueOf(maxAttempts));
        return new UserLockInMemoryServiceImpl();
    }

    private void getNextLoginTime(UserLockInMemoryService lockInMemoryService, int attempt, int lockoutTime) {
        long now = System.currentTimeMillis();
        long nextLoginTime = lockInMemoryService.getNextLoginTime(attempt, now);
        assertThat(nextLoginTime).isEqualTo(lockoutTime == -1 ? -1 : now + lockoutTime);
    }

    @DataProvider
    private Object[][] dataProvider1() {
        return new Object[][] {
                {1, -1,},
                {2, 128},
                {3, 129},
                {4, 129},
                {100, 129}
        };
    }

    @DataProvider
    private Object[][] dataProvider2() {
        return new Object[][] {
                {2, -1,},
                {3, 128},
                {4, 256},
                {5, 512},
                {6, 512}
        };
    }

    @DataProvider
    private Object[][] dataProvider3() {
        return new Object[][] {
                {1, 128},
                {2, 256},
                {4, 256},
        };
    }

    @DataProvider
    private Object[][] dataProvider4() {
        return new Object[][] {
                {1, -1},
                {2, 1000},
                {3, 2000},
                {4, 6000},
                {5, 16000},
                {6, 33000},
                {7, 56000},
                {10, 60000}
        };
    }

    @DataProvider
    private Object[][] testZeroBlockDelayDataProvider() {
        return new Object[][] {
                {1, -1},
                {2, -1},
                {10, -1},
                {100, -1},
        };
    }

    @DataProvider
    private Object[][] testZeroMaxDelayDataProvider() {
        return new Object[][] {
                {1, -1},
                {2, -1},
                {10, -1},
                {100, -1},
        };
    }
}