package org.artifactory.ui.rest.service.artifacts.browse.treebrowser.tabs.alpine;

import org.artifactory.addon.AddonsManager;
import org.artifactory.addon.alpine.AlpineAddon;
import org.artifactory.addon.alpine.AlpineMetadataInfo;
import org.artifactory.api.context.ContextHelper;
import org.artifactory.api.repo.RepositoryService;
import org.artifactory.api.security.AuthorizationService;
import org.artifactory.repo.RepoPath;
import org.artifactory.repo.RepoPathFactory;
import org.artifactory.rest.common.service.ArtifactoryRestRequest;
import org.artifactory.rest.common.service.RestResponse;
import org.artifactory.rest.common.service.RestService;
import org.artifactory.ui.rest.model.artifacts.browse.treebrowser.tabs.alpine.AlpineArtifactInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletResponse;

/**
 * Service for fetching the Alpine metadata for the Info tab in the UI
 *
 * @author Yuval Reches
 */
@Component
@Scope(BeanDefinition.SCOPE_PROTOTYPE)
public class AlpineViewService implements RestService {

    @Autowired
    private AuthorizationService authorizationService;

    @Autowired
    private RepositoryService repositoryService;

    @Override
    public void execute(ArtifactoryRestRequest request, RestResponse response) {
        AlpineArtifactInfo alpineArtifactInfo = (AlpineArtifactInfo) request.getImodel();
        RepoPath repoPath = RepoPathFactory.create(alpineArtifactInfo.getRepoKey(), alpineArtifactInfo.getPath());
        if (repositoryService.isVirtualRepoExist(repoPath.getRepoKey())) {
            repoPath = repositoryService.getVirtualFileInfo(repoPath).getRepoPath();
        }
        // Assert permission checks
        if (!authorizationService.canRead(repoPath)) {
            response.responseCode(HttpServletResponse.SC_FORBIDDEN).buildResponse();
            return;
        }
        // get Alpine Metadata
        AlpineArtifactInfo alpineMetadata = getAlpineMetaData(alpineArtifactInfo, repoPath);
        // Update response with model data
        response.iModel(alpineMetadata);
    }

    /**
     * @return Alpine Metadata model
     */
    private AlpineArtifactInfo getAlpineMetaData(AlpineArtifactInfo alpineArtifactInfo, RepoPath repoPath) {
        AddonsManager addonsManager = ContextHelper.get().beanForType(AddonsManager.class);
        AlpineAddon alpineAddon = addonsManager.addonByType(AlpineAddon.class);
        if (alpineAddon != null) {
            AlpineMetadataInfo alpineMetadata = alpineAddon.getMetadataIntoUiModel(repoPath);
            alpineArtifactInfo.setAlpineInfo(alpineMetadata.getAlpineInfo());
            alpineArtifactInfo.setAlpineDependencies(alpineMetadata.getAlpineDependencies());
        }
        return alpineArtifactInfo;
    }
}
